HttpClient class abstract

Interface for HTTP client operations (Interface Segregation)

This interface defines the contract for HTTP client implementations. It follows the Interface Segregation Principle by providing only the essential methods needed for HTTP operations.

Implementers

Constructors

HttpClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Dispose resources
execute<T>(HttpRequest request, {T parser(dynamic)?}) Future<HttpResponse<T>>
Execute HTTP request
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited