RequestBuilder class abstract

Interface for request building (Single Responsibility)

Implementers

Constructors

RequestBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build({required String method, required String path, Map<String, String>? headers, Map<String, dynamic>? queryParameters, dynamic body, Duration? timeout, bool? useToken, int? maxRetries, List<int>? retryStatusCodes, bool? rethrowExceptions}) HttpRequest
Build HTTP request
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited