TokenManager class abstract

Combined interface for complete token management (Composition over inheritance)

Implemented types
Implementers

Constructors

TokenManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearTokens() Future<void>
Clear all tokens
inherited
getRefreshToken() Future<String?>
Get the current refresh token
inherited
getToken() Future<String?>
Get the current access token
inherited
hasValidTokens() Future<bool>
Check if tokens are available and valid
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken() Future<String?>
Refresh the access token and return the new token Returns null if refresh failed
inherited
saveAccessToken(String token) Future<void>
Save access token
inherited
saveRefreshToken(String token) Future<void>
Save refresh token
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited