HttpClientImpl class
HTTP client implementation (Single Responsibility)
- Implemented types
Constructors
- HttpClientImpl({Client? client})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
Dispose resources
override
-
execute<
T> (HttpRequest request, {T parser(dynamic)?}) → Future< HttpResponse< T> > -
Execute HTTP request
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited