dispose method
Dispose resources
Cleans up any resources used by the HTTP client. This should be called when the client is no longer needed.
Implementation
@override
void dispose() {
_client.close();
}
Dispose resources
Cleans up any resources used by the HTTP client. This should be called when the client is no longer needed.
@override
void dispose() {
_client.close();
}