NetworkLoggerImpl class

Network logger implementation (Single Responsibility)

Implemented types

Constructors

NetworkLoggerImpl({Logger? logger, bool enableRequestLogging = false, bool enableResponseLogging = false})

Properties

enableRequestLogging bool
final
enableResponseLogging bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

logError(String message, [dynamic error]) → void
Log error
override
logRequest(HttpRequest request) → void
Log request
override
logResponse(HttpResponse response) → void
Log response
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited