FunctionRefreshTokenProvider class
Simple function-based refresh token provider
- Implemented types
Constructors
-
FunctionRefreshTokenProvider(Future<
String?> _getRefreshToken()) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getRefreshToken(
) → Future< String?> -
Get the current refresh token
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited