FunctionTokenProvider class

Simple function-based token provider (Composition over inheritance)

Implemented types

Constructors

FunctionTokenProvider(Future<String?> _getToken())
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getToken() Future<String?>
Get the current access token
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited