FunctionTokenRefresher class

Simple function-based token refresher

Implemented types

Constructors

FunctionTokenRefresher(Future<String?> _refreshToken())
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshToken() Future<String?>
Refresh the access token and return the new token Returns null if refresh failed
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited